%{         

#include <aterm2.h>
#include "prolog-term-grm.h"
#include <math.h>

static ATerm mkstring();
void yyerror(char *msg);

FILE *outfile;

#define lexerror(x, y) fprintf(stderr, "%s %s\n", x, y)

#define YY_DECL  int yylex(YYSTYPE *lvalp)

extern char file_name[256];

int line = 0;

%}

layout   [ \t\n\r]
id       [a-zA-Z][a-zA-Z0-9_]*
intconst [0-9]+
dbli     [.][0-9]+ 
dbliE    [.][0-9]+[eE][+\-]?[0-9]+
dblii    [0-9]+[.][0-9]*([eE][+\-]?[0-9]+)?
dbliii   [0-9]+[eE][\+\-]?[0-9]+
qitem    [^'\\]|([\\]["'])
qname    [']{qitem}+[']
op       [-+*=!~/?<>@#$%^&|\\]+ 
%option yylineno
%option noyywrap

%%

"'.'"            { ECHO ; return LCONSTR; }
"-"              { ECHO ; (*lvalp).term = (ATerm) ATmakeString("-"); return MINUS; }
"[]"             { ECHO ; return MTLIST; }
[.]              { ECHO ; return '.' ; }
[(]              { ECHO ; return '(' ; }
[)]              { ECHO ; return ')' ; }
[,]              { ECHO ; return ',' ; }
{op}             { ECHO ; (*lvalp).term = (ATerm) ATmakeString(yytext); 
                   ATfprintf(stderr, "OPERATOR: %s -> %t\n", yytext, (*lvalp).term); 
                   return OPERATOR ; }
{id}             { ECHO ; (*lvalp).term = (ATerm) ATmakeString(yytext); 
                   ATfprintf(stderr, "ID: %s -> %t\n", yytext, (*lvalp).term); 
                   return ID; }
{intconst}       { ECHO ; (*lvalp).num = atoi(yytext);  
                   ATfprintf(stderr, "INTCONST: %s -> %d\n", yytext, (*lvalp).num); 
                   return INTCONST; }
{dbli}           { ECHO ; (*lvalp).real = atof(yytext);  
                   ATfprintf(stderr, "DBLI: %s -> %r\n", yytext, (*lvalp).real); 
                   return DBLCONST; }
{dbliE}          { ECHO ; (*lvalp).real = atof(yytext); return DBLCONST; }
{dblii}          { ECHO ; (*lvalp).real = atof(yytext); return DBLCONST; }
{dbliii}         { ECHO ; (*lvalp).real = atof(yytext); return DBLCONST; }
{qname}          { ECHO ; (*lvalp).term = (ATerm)ATmakeString(yytext);  
                   ATfprintf(stderr, "QNAME: %s -> %t\n", yytext, (*lvalp).term); 
                   return QNAME; }
{layout}         { ECHO ; }
.	         { ECHO ; lexerror ("ignoring illegal character", yytext); }
<<EOF>>          {//ATfprintf(stderr, "%s: %d lines\n", file_name, line);
                  yyterminate();}

%%
